%define ppconfdir conf/redhat

Name:           puppet  
Version:        3.6.2
%define	subrel	1
Release:        %mkrel 3
Summary:        System Automation and Configuration Management Software
License:        Apache Software License 
Group:          Monitoring
URL:            http://www.puppetlabs.com/
Source0:        http://puppetlabs.com/downloads/puppet/%{name}-%{version}.tar.gz
Source100:      puppet.service
Source101:      puppetmaster.service
Source102:      %{name}-tmpfiles.conf
Patch7:		0007-CVE-2017-2295.patch
BuildArch:      noarch
BuildRequires:	ruby
BuildRequires:	ruby-hiera
BuildRequires:	facter
Requires:       facter
Recommends:       vim-puppet
Recommends:       emacs-puppet
Requires(post): systemd >= %{systemd_required_version}
Requires(pre):  rpm-helper
Requires(post): rpm-helper
Requires(preun):rpm-helper
Obsoletes:      puppet3

%description
Puppet lets you centrally manage every important aspect of your system using a 
cross-platform specification language that manages all the separate elements 
normally aggregated in different files, like users, cron jobs, and hosts, 
along with obviously discrete elements like packages, services, and files.

This package provide the puppet client daemon.

%package server
Group:          Monitoring 
Summary:        Server for the puppet system management tool
Requires:       %{name} = %{version}
Requires(post): rpm-helper
Requires(preun):rpm-helper
Obsoletes:      puppet3-server
                
%description server
Provides the central puppet server daemon (puppetmaster) which provides
manifests to clients.
The server can also function as a certificate authority and file server.

%package -n vim-puppet
Group:          Editors
Summary:        Syntax highlighting for puppet manifests in vim
Obsoletes:      vim-puppet3
                
%description -n vim-puppet
The vim-puppet package provides filetype detection and syntax highlighting for
puppet manifests (files ending with ".pp").

%package -n emacs-puppet
Group:          Editors
Summary:        Syntax highlighting for puppet manifests in emacs
Obsoletes:      emacs-puppet3
                
%description -n emacs-puppet
The emacs-puppet package provides filetype detection and syntax highlighting for
puppet manifests (files ending with ".pp").

%prep
%setup -q
%apply_patches

# Fix some rpmlint complaints
for f in external/nagios.rb relationship.rb; do
    sed -i -e '1d' lib/puppet/$f
done
chmod +x ext/puppet-load.rb ext/regexp_nodes/regexp_nodes.rb

%build

%install
ruby install.rb \
    --destdir=%{buildroot} \
    --sitelibdir=%{ruby_vendorlibdir} \
    --quick \
    --no-rdoc

install -d -m 0755 %{buildroot}%{_sysconfdir}/%{name}/manifests
install -d -m 0755 %{buildroot}%{_sysconfdir}/%{name}/modules
install -d -m 0755 %{buildroot}%{_datadir}/puppet/modules
install -d -m 0755 %{buildroot}%{_localstatedir}/lib/puppet
install -d -m 0755 %{buildroot}%{_localstatedir}/log/puppet

install -D -m 644 ext/systemd/puppet.service \
    %{buildroot}%{_unitdir}/puppet.service
install -D -m 644 ext/systemd/puppetmaster.service \
    %{buildroot}%{_unitdir}/puppetmaster.service

install -D -m 644 ext/redhat/fileserver.conf \
    %{buildroot}%{_sysconfdir}/puppet/fileserver.conf
install -D -m 644 ext/redhat/puppet.conf \
    %{buildroot}%{_sysconfdir}/puppet/puppet.conf
install -D -m 644 %{SOURCE102} %{buildroot}%{_tmpfilesdir}/puppet.conf

# logrotate
install -d  %{buildroot}%{_sysconfdir}/logrotate.d
cat > %{buildroot}%{_sysconfdir}/logrotate.d/puppetagent <<EOF
/var/log/puppet/*log {
    create 0644 puppet puppet
    sharedscripts
    postrotate
        /bin/systemctl reload puppetagent.service > /dev/null 2>&1 || true
    endscript
}
EOF
cat > %{buildroot}%{_sysconfdir}/logrotate.d/puppetmaster <<EOF
/var/log/puppet/*log {
    create 0644 puppet puppet
    sharedscripts
    postrotate
        /bin/systemctl reload puppetmaster.service > /dev/null 2>&1 || true
    endscript
}
EOF

install -d %{buildroot}%{_datadir}/puppet
cp -a ext/ %{buildroot}%{_datadir}/puppet
# emacs and vim bits are installed elsewhere
rm -rf %{buildroot}%{_datadir}/puppet/ext/{emacs,vim}
# remove misc packaging artifacts in source not applicable to rpm
rm -rf %{buildroot}%{_datadir}/puppet/ext/{gentoo,freebsd,solaris,suse,windows,osx,ips,debian}
rm -f %{buildroot}%{_datadir}/puppet/ext/{build_defaults.yaml,project_data.yaml}
rm -f %{buildroot}%{_datadir}/puppet/ext/redhat/*.init

# vim syntax file
vimdir=%{buildroot}%{_datadir}/vim
install -D -m 644 ext/vim/syntax/puppet.vim $vimdir/syntax/puppet.vim
install -D -m 644 ext/vim/ftdetect/puppet.vim $vimdir/ftdetect/puppet.vim

# emacs syntax file
emacsdir=%{buildroot}%{_datadir}/emacs/site-lisp
install -D -m 644 ext/emacs/puppet-mode.el $emacsdir/puppet-mode.el
install -D -m 644 ext/emacs/puppet-mode-init.el \
    $emacsdir/site-start.d/puppet-mode-init.el

# logcheck files
logcheckdir=%{buildroot}%{_sysconfdir}/logcheck/
install -D -m 644 ext/logcheck/puppet $logcheckdir/ignore.d.server/puppet
install -D -m 644 ext/logcheck/puppet $logcheckdir/ignore.d.workstation/puppet

%pre
%_pre_useradd puppet %{_localstatedir}/lib/%{name} /sbin/nologin 

%post
%_tmpfilescreate %{name}
%_post_service puppet

%preun
%_preun_service puppet

%post server
%_post_service puppetmaster

%preun server
%_preun_service puppetmaster 

%files
%doc LICENSE README.md examples
%dir %{_sysconfdir}/puppet
%dir %{_sysconfdir}/puppet/modules
%config(noreplace) %{_sysconfdir}/puppet/puppet.conf
%config(noreplace) %{_sysconfdir}/puppet/auth.conf
%{_sysconfdir}/logcheck/ignore.d.workstation/puppet
%{_sysconfdir}/logcheck/ignore.d.server/puppet
%{_tmpfilesdir}/puppet.conf
%{_unitdir}/puppet.service
%{_bindir}/puppet
%{_bindir}/extlookup2hiera
%{ruby_vendorlibdir}/hiera
%{ruby_vendorlibdir}/hiera_puppet.rb
%config(noreplace) %{_sysconfdir}/logrotate.d/puppetagent
%{ruby_vendorlibdir}/puppet
%{ruby_vendorlibdir}/puppet.rb
%{ruby_vendorlibdir}/puppetx
%{ruby_vendorlibdir}/puppetx.rb
%{ruby_vendorlibdir}/semver.rb
%{_datadir}/puppet
%attr(-,puppet,puppet) %{_localstatedir}/log/puppet
%attr(-,puppet,puppet) %{_localstatedir}/lib/puppet
%{_mandir}/man5/puppet.conf.5.*
%{_mandir}/man8/puppet.8.*
%{_mandir}/man8/puppet-agent.8.*
%{_mandir}/man8/puppet-apply.8.*
%{_mandir}/man8/puppet-catalog.8.*
%{_mandir}/man8/puppet-describe.8.*
%{_mandir}/man8/puppet-ca.8.*
%{_mandir}/man8/puppet-cert.8.*
%{_mandir}/man8/puppet-certificate.8.*
%{_mandir}/man8/puppet-certificate_request.8.*
%{_mandir}/man8/puppet-certificate_revocation_list.8.*
%{_mandir}/man8/puppet-config.8.*
%{_mandir}/man8/puppet-device.8.*
%{_mandir}/man8/puppet-doc.8.*
%{_mandir}/man8/puppet-facts.8.*
%{_mandir}/man8/puppet-file.8.*
%{_mandir}/man8/puppet-filebucket.8.*
%{_mandir}/man8/puppet-help.8.*
%{_mandir}/man8/puppet-inspect.8.*
%{_mandir}/man8/puppet-instrumentation_data.8.*
%{_mandir}/man8/puppet-instrumentation_listener.8.*
%{_mandir}/man8/puppet-instrumentation_probe.8.*
%{_mandir}/man8/puppet-key.8.*
%{_mandir}/man8/puppet-man.8.*
%{_mandir}/man8/puppet-module.8.*
%{_mandir}/man8/puppet-node.8.*
%{_mandir}/man8/puppet-parser.8.*
%{_mandir}/man8/puppet-plugin.8.*
%{_mandir}/man8/puppet-report.8.*
%{_mandir}/man8/puppet-resource.8.*
%{_mandir}/man8/puppet-resource_type.8.*
%{_mandir}/man8/puppet-secret_agent.8.*
%{_mandir}/man8/puppet-status.8.*
%{_mandir}/man8/extlookup2hiera.8.*

%files server
%{_unitdir}/puppetmaster.service
%config(noreplace) %{_sysconfdir}/puppet/fileserver.conf
%config(noreplace) %{_sysconfdir}/logrotate.d/puppetmaster
%dir %{_sysconfdir}/puppet/manifests
%{_mandir}/man8/puppet-kick.8.*
%{_mandir}/man8/puppet-master.8.*
%{_mandir}/man8/puppet-queue.8.*

%files -n vim-puppet
%{_datadir}/vim/syntax/puppet.vim
%{_datadir}/vim/ftdetect/puppet.vim

%files -n emacs-puppet
%{_datadir}/emacs/site-lisp/puppet-mode.el
%{_datadir}/emacs/site-lisp/site-start.d/puppet-mode-init.el


%changelog
* Sun Jun 04 2017 luigiwalser <luigiwalser> 3.6.2-3.1.mga5
+ Revision: 1106605
- add patch from debian to fix CVE-2017-2295

* Wed Oct 15 2014 umeabot <umeabot> 3.6.2-3.mga5
+ Revision: 750987
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 3.6.2-2.mga5
+ Revision: 687835
- Mageia 5 Mass Rebuild

  + tv <tv>
    - s/uggests:/Recommends:/

* Mon Jun 16 2014 guillomovitch <guillomovitch> 3.6.2-1.mga5
+ Revision: 637405
- new version 3.6.2

* Mon Jan 13 2014 guillomovitch <guillomovitch> 3.4.2-1.mga4
+ Revision: 566475
+ rebuild (emptylog)

* Fri Jan 03 2014 guillomovitch <guillomovitch> 3.4.1-1.mga4
+ Revision: 564049
- new version 3.4.1

* Sat Oct 19 2013 umeabot <umeabot> 3.2.4-2.mga4
+ Revision: 532362
- Mageia 4 Mass Rebuild

* Tue Aug 20 2013 guillomovitch <guillomovitch> 3.2.4-1.mga4
+ Revision: 468116
- new version

* Wed Jun 19 2013 boklm <boklm> 3.2.2-1.mga4
+ Revision: 445092
- Update to version 3.2.2, fixing CVE-2013-3567 (Unauthenticated Remote
  Code Execution Vulnerability)

* Fri May 24 2013 guillomovitch <guillomovitch> 3.2.1-2.mga4
+ Revision: 426167
- new version

* Sat May 11 2013 guillomovitch <guillomovitch> 2.7.21-2.mga3
+ Revision: 413007
- use systemctl in logrotate, instead of sysinit script

* Fri Apr 05 2013 guillomovitch <guillomovitch> 2.7.21-1.mga3
+ Revision: 408245
- new version

  + neoclust <neoclust>
    - New sec fixes version

  + colin <colin>
    - Add systemd requires and general post/pre fixes (mga#9302)

* Sun Jan 13 2013 umeabot <umeabot> 2.7.20-3.mga3
+ Revision: 378317
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Dec 16 2012 colin <colin> 2.7.20-2.mga3
+ Revision: 331700
- Switch to tmpfiles for /run dirs

* Wed Dec 12 2012 nanardon <nanardon> 2.7.20-1.mga3
+ Revision: 329851
- 2.7.20

* Mon Aug 13 2012 guillomovitch <guillomovitch> 2.7.18-1.mga3
+ Revision: 281054
- new version

* Fri Jul 06 2012 guillomovitch <guillomovitch> 2.7.17-1.mga3
+ Revision: 268416
- new version

* Mon Jun 11 2012 guillomovitch <guillomovitch> 2.7.14-1.mga3
+ Revision: 259755
- split emacs and vim extensions into distinct subpackages
- new version
- systemd support
- drop sysinit support

* Sat Feb 25 2012 misc <misc> 2.7.11-1.mga2
+ Revision: 214730
- new version 2.7.11 ( security and maintainance fix )

* Fri Feb 17 2012 misc <misc> 2.7.10-1.mga2
+ Revision: 210067
- upgrade to 2.7.10

* Mon Oct 24 2011 misc <misc> 2.7.6-1.mga2
+ Revision: 157871
- new version ( security issue )

* Mon Oct 03 2011 misc <misc> 2.7.5-1.mga2
+ Revision: 151298
- new version
- reupload the new tarball
- remove clean and defattr
- new version

* Thu Jun 23 2011 misc <misc> 2.7.1-1.mga2
+ Revision: 112565
- new version of puppet

* Wed May 04 2011 misc <misc> 2.6.8-1.mga1
+ Revision: 94686
- upgrade to 2.6.8, maintainance release

* Tue Apr 05 2011 misc <misc> 2.6.7-1.mga1
+ Revision: 80806
- update to latest version

* Mon Jan 24 2011 misc <misc> 2.6.4-1.mga1
+ Revision: 35788
- clean version specific and extranous requires
- imported package puppet


* Thu Dec 02 2010 Michael Scherer <misc@mandriva.org> 2.6.4-1mdv2011.0
+ Revision: 604643
- update to 2.6.4 ( security fix )

* Mon Nov 29 2010 Michael Scherer <misc@mandriva.org> 2.6.3-1mdv2011.0
+ Revision: 603105
- update to new version 2.6.3

* Mon Nov 01 2010 Michael Scherer <misc@mandriva.org> 2.6.2-1mdv2011.0
+ Revision: 591482
- update to new version 2.6.2

* Sat Sep 18 2010 Guillaume Rousse <guillomovitch@mandriva.org> 2.6.1-1mdv2011.0
+ Revision: 579557
- update to new version 2.6.1

* Wed Aug 25 2010 Michael Scherer <misc@mandriva.org> 2.6.0-1mdv2011.0
+ Revision: 573154
- update to 2.6.0 version
- really fix the issue of puppet being killed on log rotation

* Thu Aug 05 2010 Michael Scherer <misc@mandriva.org> 0.25.4-2mdv2011.0
+ Revision: 566099
- fix initscript so reload do not kill puppet, by sending SIGTERM instead of SIGHUP ( as seen on cooker, but not on my 2010.1 server )

* Mon Apr 12 2010 Michael Scherer <misc@mandriva.org> 0.25.4-1mdv2010.1
+ Revision: 533709
- fix Url
- update to 0.25.4
- use install.rb instead of doing it by hand
- add man pages

* Thu Jan 21 2010 Michael Scherer <misc@mandriva.org> 0.24.7-3mdv2010.1
+ Revision: 494418
- fix initscript configuration

* Sun Aug 16 2009 Michael Scherer <misc@mandriva.org> 0.24.7-2mdv2010.0
+ Revision: 416752
- fix loop on status, patch by roudoudou, bug #40414
- fix error when no site.pp exist, bug #52895

* Tue Dec 30 2008 Guillaume Rousse <guillomovitch@mandriva.org> 0.24.7-1mdv2009.1
+ Revision: 321401
- update to new version 0.24.7

* Fri Sep 12 2008 Olivier Thauvin <nanardon@mandriva.org> 0.24.5-2mdv2009.0
+ Revision: 284057
- fix sysconfig/* filename

* Fri Aug 01 2008 Michael Scherer <misc@mandriva.org> 0.24.5-1mdv2009.0
+ Revision: 259425
- new version

* Fri Aug 01 2008 Thierry Vignaud <tv@mandriva.org> 0.23.2-4mdv2009.0
+ Revision: 259355
- rebuild

* Thu Jul 24 2008 Thierry Vignaud <tv@mandriva.org> 0.23.2-3mdv2009.0
+ Revision: 247238
- rebuild
- fix description-line-too-long
- kill re-definition of %%buildroot on Pixel's request

  + Pixel <pixel@mandriva.com>
    - adapt to %%_localstatedir now being /var instead of /var/lib (#22312)

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

* Tue Oct 30 2007 Funda Wang <fwang@mandriva.org> 0.23.2-1mdv2008.1
+ Revision: 103930
- BR ruby
- import puppet


* Thu Oct 30 2007 roudoud0u <roudoud0u@free.fr> - 0.23.2-1
- Initial Mandriva rpm package (based on David Lutterkort spec file)

* Thu Jul 26 2007 David Lutterkort <dlutter@redhat.com> - 0.23.1-1
- Remove old config files

* Wed Jun 20 2007 David Lutterkort <dlutter@redhat.com> - 0.23.0-1
- Install one puppet.conf instead of old config files, keep old configs 
  around to ease update
- Use plain shell commands in install instead of macros

* Wed May  2 2007 David Lutterkort <dlutter@redhat.com> - 0.22.4-1
- New version

* Thu Mar 29 2007 David Lutterkort <dlutter@redhat.com> - 0.22.3-1
- Claim ownership of _sysconfdir/puppet (bz 233908)

* Mon Mar 19 2007 David Lutterkort <dlutter@redhat.com> - 0.22.2-1
- Set puppet's homedir to /var/lib/puppet, not /var/puppet
- Remove no-lockdir patch, not needed anymore

* Mon Feb 12 2007 David Lutterkort <dlutter@redhat.com> - 0.22.1-2
- Fix bogus config parameter in puppetd.conf

* Sat Feb  3 2007 David Lutterkort <dlutter@redhat.com> - 0.22.1-1
- New version

* Fri Jan  5 2007 David Lutterkort <dlutter@redhat.com> - 0.22.0-1
- New version

* Mon Nov 20 2006 David Lutterkort <dlutter@redhat.com> - 0.20.1-2
- Make require ruby(abi) and buildarch: noarch conditional for fedora 5 or
  later to allow building on older fedora releases

* Mon Nov 13 2006 David Lutterkort <dlutter@redhat.com> - 0.20.1-1
- New version

* Mon Oct 23 2006 David Lutterkort <dlutter@redhat.com> - 0.20.0-1
- New version

* Tue Sep 26 2006 David Lutterkort <dlutter@redhat.com> - 0.19.3-1
- New version

* Mon Sep 18 2006 David Lutterkort <dlutter@redhat.com> - 0.19.1-1
- New version

* Thu Sep  7 2006 David Lutterkort <dlutter@redhat.com> - 0.19.0-1
- New version

* Tue Aug  1 2006 David Lutterkort <dlutter@redhat.com> - 0.18.4-2
- Use /usr/bin/ruby directly instead of /usr/bin/env ruby in
  executables. Otherwise, initscripts break since pidof can't find the
  right process

* Tue Aug  1 2006 David Lutterkort <dlutter@redhat.com> - 0.18.4-1
- New version

* Fri Jul 14 2006 David Lutterkort <dlutter@redhat.com> - 0.18.3-1
- New version

* Wed Jul  5 2006 David Lutterkort <dlutter@redhat.com> - 0.18.2-1
- New version

* Wed Jun 28 2006 David Lutterkort <dlutter@redhat.com> - 0.18.1-1
- Removed lsb-config.patch and yumrepo.patch since they are upstream now

* Mon Jun 19 2006 David Lutterkort <dlutter@redhat.com> - 0.18.0-1
- Patch config for LSB compliance (lsb-config.patch)
- Changed config moves /var/puppet to /var/lib/puppet, /etc/puppet/ssl 
  to /var/lib/puppet, /etc/puppet/clases.txt to /var/lib/puppet/classes.txt,
  /etc/puppet/localconfig.yaml to /var/lib/puppet/localconfig.yaml

* Fri May 19 2006 David Lutterkort <dlutter@redhat.com> - 0.17.2-1
- Added /usr/bin/puppetrun to server subpackage
- Backported patch for yumrepo type (yumrepo.patch)

* Wed May  3 2006 David Lutterkort <dlutter@redhat.com> - 0.16.4-1
- Rebuilt

* Fri Apr 21 2006 David Lutterkort <dlutter@redhat.com> - 0.16.0-1
- Fix default file permissions in server subpackage
- Run puppetmaster as user puppet
- rebuilt for 0.16.0

* Mon Apr 17 2006 David Lutterkort <dlutter@redhat.com> - 0.15.3-2
- Don't create empty log files in post-install scriptlet

* Fri Apr  7 2006 David Lutterkort <dlutter@redhat.com> - 0.15.3-1
- Rebuilt for new version

* Wed Mar 22 2006 David Lutterkort <dlutter@redhat.com> - 0.15.1-1
- Patch0: Run puppetmaster as root; running as puppet is not ready 
  for primetime

* Mon Mar 13 2006 David Lutterkort <dlutter@redhat.com> - 0.15.0-1
- Commented out noarch; requires fix for bz184199

* Mon Mar  6 2006 David Lutterkort <dlutter@redhat.com> - 0.14.0-1
- Added BuildRequires for ruby

* Wed Mar  1 2006 David Lutterkort <dlutter@redhat.com> - 0.13.5-1
- Removed use of fedora-usermgmt. It is not required for Fedora Extras and
  makes it unnecessarily hard to use this rpm outside of Fedora. Just
  allocate the puppet uid/gid dynamically

* Sun Feb 19 2006 David Lutterkort <dlutter@redhat.com> - 0.13.0-4
- Use fedora-usermgmt to create puppet user/group. Use uid/gid 24. Fixed 
problem with listing fileserver.conf and puppetmaster.conf twice

* Wed Feb  8 2006 David Lutterkort <dlutter@redhat.com> - 0.13.0-3
- Fix puppetd.conf

* Wed Feb  8 2006 David Lutterkort <dlutter@redhat.com> - 0.13.0-2
- Changes to run puppetmaster as user puppet

* Mon Feb  6 2006 David Lutterkort <dlutter@redhat.com> - 0.13.0-1
- Don't mark initscripts as config files

* Mon Feb  6 2006 David Lutterkort <dlutter@redhat.com> - 0.12.0-2
- Fix BuildRoot. Add dist to release

* Tue Jan 17 2006 David Lutterkort <dlutter@redhat.com> - 0.11.0-1
- Rebuild

* Thu Jan 12 2006 David Lutterkort <dlutter@redhat.com> - 0.10.2-1
- Updated for 0.10.2 Fixed minor kink in how Source is given

* Wed Jan 11 2006 David Lutterkort <dlutter@redhat.com> - 0.10.1-3
- Added basic fileserver.conf

* Wed Jan 11 2006 David Lutterkort <dlutter@redhat.com> - 0.10.1-1
- Updated. Moved installation of library files to sitelibdir. Pulled 
initscripts into separate files. Folded tools rpm into server

* Thu Nov 24 2005 Duane Griffin <d.griffin@psenterprise.com>
- Added init scripts for the client

* Wed Nov 23 2005 Duane Griffin <d.griffin@psenterprise.com>
- First packaging
